//
//  OpenPlatforActionViewController.m
//  OpenSDKDemo_Example
//
//  Created by Jiny.du on 2019/7/22.
//  Copyright © 2019 bytedance.co All rights reserved.
//

#import "OpenPlatformShareViewController.h"

#import "OpenPlatformUIDefine.h"
#import "OpenPlatforActionViewController.h"
#import "OpenPlatformSectionCell.h"
#import "OpenPlatformActionDataControl.h"
#import "OpenPlatformSession.h"
#import "OpenPlatformCellProtocol.h"
#import "OpenPlatformActionView.h"
#import "UIAlertController+Addition.h"


@interface OpenPlatforActionViewController ()<UITableViewDelegate, UITableViewDataSource>
@property (nonatomic, strong) UITableView *tableView;
@property (nonatomic, strong) OpenPlatformActionDataControl *dataControl;
@property (nonatomic, strong) OpenPlatformActionView *actionView;

@end

@implementation OpenPlatforActionViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    self.view.backgroundColor = [UIColor demo_colorWithHex:@"#f5f5f5"];
    self.tableView = [[UITableView alloc] initWithFrame:self.view.frame style:UITableViewStyleGrouped];
    self.tableView.dataSource = self;
    self.tableView.delegate   = self;
    self.tableView.backgroundColor = YAMBGDefualtColor;
    self.tableView.separatorStyle = UITableViewCellSeparatorStyleNone;
    [self.tableView registerClass:[OpenPlatformSectionCell class]
           forCellReuseIdentifier:@"OpenPlatformSession"];
    self.tableView.contentInset = UIEdgeInsetsMake(0, 0, 20, 0);
    [self.view addSubview:self.tableView];
    self.title = @"China Actions";
    
    self.actionView = [[OpenPlatformActionView alloc] initWithFrame:CGRectZero];
    [self.actionView.leftButton addTarget:self action:@selector(tapAuth) forControlEvents:UIControlEventTouchUpInside];
    [self.actionView.rightButton addTarget:self action:@selector(tapShare) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:self.actionView];
}

- (void)viewDidLayoutSubviews
{
    [super viewDidLayoutSubviews];
    self.tableView.frame = self.view.bounds;
    self.actionView.x = 0;
    self.actionView.width = self.view.width;
    self.actionView.height = 60 + BOTTOM_SAFEAREA_HEIGHT;
    self.actionView.y = self.view.height - BOTTOM_SAFEAREA_HEIGHT - 60;
    [self.actionView setNeedsLayout];
    [self.actionView layoutIfNeeded];
}

- (void)setAppType:(NSInteger)appType
{
    _appType = appType;
    self.dataControl = [[OpenPlatformActionDataControl alloc] initWithAppType:appType];
    [self.tableView reloadData];
}

#pragma mark - TableView Delegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    [tableView deselectRowAtIndexPath:indexPath animated:NO];
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
{
    return self.dataControl.sessions[indexPath.section].heightForSession;
}

- (CGFloat)tableView:(UITableView *)tableView heightForFooterInSection:(NSInteger)section
{
    return .1f;
}

- (CGFloat)tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section
{
    return 25.f;
}

- (UIView *)tableView:(UITableView *)tableView viewForFooterInSection:(NSInteger)section
{
    return [[UIView alloc] init];
}

- (void)scrollViewDidScroll:(UIScrollView *)scrollView
{
    [self.view endEditing:YES];
}

#pragma mark - TableView DataSource
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    OpenPlatformSession *item = self.dataControl.sessions[indexPath.row];
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:NSStringFromClass([OpenPlatformSession class])];
    if ([cell conformsToProtocol:@protocol(OpenPlatformSectionProtocol)]) {
        [((id<OpenPlatformSectionProtocol>)cell) configWithSectionItem:item];
    }
    return cell;
}

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return self.dataControl.sessions.count;
}

#pragma mark - Action
- (void)tapAuth
{
    DouyinOpenSDKAuthRequest *request = [[DouyinOpenSDKAuthRequest alloc] init];
    request.permissions = [NSOrderedSet orderedSetWithObject:@"user_info"];
    //可选附加权限（如有），用户可选择勾选/不勾选
//    request.additionalPermissions = [NSOrderedSet orderedSetWithObjects:@{@"permission":@"friend_relation",@"defaultChecked":@"1"}, @{@"permission":@"message",@"defaultChecked":@"0"}, nil];
    __weak typeof(self) ws = self;
    [request sendAuthRequestViewController:self completeBlock:^(DouyinOpenSDKAuthResponse * _Nonnull resp) {
        __strong typeof(ws) sf = ws;
        NSString *alertString = nil;
        if (resp.errCode == 0) {
            alertString = [NSString stringWithFormat:@"Author Success Code : %@, permission : %@",resp.code, resp.grantedPermissions];
        } else{
            alertString = [NSString stringWithFormat:@"Author failed code : %@, msg : %@",@(resp.errCode), resp.errString];
        }
        [UIAlertController showMsg:alertString inVC:sf];
    }];
}

- (void)tapShare
{
    OpenPlatformShareViewController *vc = [[OpenPlatformShareViewController alloc] init];
    vc.appType = self.appType;
    [self.navigationController pushViewController:vc animated:YES];
}

@end
