//
//  OpenPlatformSettingSectionCell.m
//  OpenSDKDemo
//
//  Created by Jiny.du on 2018/12/9.
//

#import "OpenPlatformSectionCell.h"
#import "OpenPlatformSectionHeaderView.h"
#import "OpenPlatformSession.h"
#import "UIView+Addition.h"
#import "OpenPlatformTableViewFactory.h"


static CGFloat const YAMSectionCardMargin = 22;
static CGFloat const YAMSectionHeaderViewHeight = 70.f;

@interface OpenPlatformSectionCell()<UITableViewDelegate, UITableViewDataSource>
@property (nonatomic, strong) UIView *bgView;
@property (nonatomic, strong) OpenPlatformSectionHeaderView *headerView;
@property (nonatomic, strong) UITableView *tableView;
@property (nonatomic, strong) OpenPlatformSession *sectionModel;
@end

@implementation OpenPlatformSectionCell

- (instancetype)initWithStyle:(UITableViewCellStyle)style reuseIdentifier:(NSString *)reuseIdentifier
{
    self = [super initWithStyle:style reuseIdentifier:reuseIdentifier];
    if (self) {
        [self commonInit];
    }
    return self;
}

- (void)commonInit
{
    self.contentView.backgroundColor = [UIColor clearColor];
    self.backgroundColor = [UIColor clearColor];
    self.selectionStyle = UITableViewCellSelectionStyleNone;
    _bgView = [[UIView alloc] init];
    _bgView.backgroundColor = [UIColor whiteColor];
    _bgView.layer.cornerRadius = 8.f;
    _bgView.clipsToBounds = YES;
    [self.contentView addSubview:_bgView];
    
    _tableView = [[UITableView alloc] initWithFrame:CGRectZero style:UITableViewStyleGrouped];
    _tableView.backgroundColor = [UIColor clearColor];
    _tableView.delegate = self;
    _tableView.estimatedRowHeight = 0;
    _tableView.estimatedSectionHeaderHeight = 0;
    _tableView.estimatedSectionFooterHeight = 0;
    _tableView.dataSource = self;
    _tableView.scrollEnabled = NO;
    [OpenPlatformTableViewFactory registActionTableView:_tableView];
    [self.bgView addSubview:_tableView];
    //TODO: add Board and shadow
    _headerView = [[OpenPlatformSectionHeaderView alloc] init];
    [self.bgView addSubview:_headerView];
}

- (void)configWithSectionItem:(OpenPlatformSession *)section
{
    _sectionModel = section;
    [self.headerView configWithSectionItem:section];
    [self.tableView reloadData];
    [self setNeedsLayout];
    [self layoutIfNeeded];
}

- (void)layoutSubviews
{
    [super layoutSubviews];
    self.bgView.frame = CGRectMake(YAMSectionCardMargin, 0, self.contentView.width - 2 * YAMSectionCardMargin, self.contentView.height);
    self.headerView.frame = CGRectMake(0, 0, self.bgView.width, YAMSectionHeaderViewHeight);
    self.tableView.frame = CGRectMake(0, self.headerView.maxY, self.bgView.width, self.contentView.height - self.headerView.maxY);
}


#pragma mark - UITabelView Delegate
- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
{
    return self.sectionModel.items[indexPath.row].heightForItem;
}

-(CGFloat)tableView:(UITableView *)tableView heightForFooterInSection:(NSInteger)section
{
    return .1f;
}

-(CGFloat)tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section
{
    return .1f;
}
#pragma mark - UITabelView DataSource
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return self.sectionModel.items.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    OpenPlatformDataItem *item = self.sectionModel.items[indexPath.row];
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:item.cellIdentify];
    if ([cell conformsToProtocol:@protocol(OpenPlatformCellProtocol)]) {
        [((id<OpenPlatformCellProtocol>)cell) configWithSettingItem:item];
    }
    return cell;
}

@end
