//
//  OpenPlatformSwitchSettingCell.m
//  OpenSDKDemo
//
//  Created by Jiny Du on 2018/9/26.
//

#import "OpenPlatformSwitchSettingCell.h"

#import "OpenPlatformUIDefine.h"

@interface OpenPlatformSwitchSettingCell()

@property (nonatomic, strong) UILabel *titleDisplayLabel;
@property (nonatomic, strong) OpenPlatformDataItem *item;
@property (nonatomic, strong) UISwitch *switchView;
@end

@implementation OpenPlatformSwitchSettingCell
- (instancetype)initWithStyle:(UITableViewCellStyle)style reuseIdentifier:(NSString *)reuseIdentifier
{
    self = [super initWithStyle:style reuseIdentifier:reuseIdentifier];
    if (self) {
        [self commonInit];
    }
    return self;
}

- (void)commonInit
{
    self.separatorInset = UIEdgeInsetsMake(0, 20, 0, 0);
    self.backgroundColor = [UIColor clearColor];
    self.titleDisplayLabel = ({
        UILabel *label = [[UILabel alloc] init];
        label.font = [UIFont systemFontOfSize:14];
        label.numberOfLines = 1;
        label.textColor = [UIColor blackColor];
        [self.contentView addSubview:label];
        label;
    });
    self.switchView = ({
        UISwitch *switchView = [[UISwitch alloc] initWithFrame:CGRectMake(0, 0, 51, 31)];
//        switchView.tintColor = YAMYellowThemeColor;
//        switchView.onTintColor = YAMYellowThemeColor;
        switchView.transform = CGAffineTransformMakeScale(0.7, 0.7);
        [switchView addTarget:self action:@selector(handlerSwitchValueChange:) forControlEvents:UIControlEventValueChanged];
        [self.contentView addSubview:switchView];
        switchView;
    });
    
}

- (void)configWithSettingItem:(OpenPlatformDataItem *)item
{
    if (item.type != OpenPlatformItemTypeSwitch) {
        return;
    }
    self.item = item;
    self.titleDisplayLabel.text = self.item.titleString;
    [self.switchView setOn:self.item.isSwitchOn];
    
    [self setNeedsLayout];
    [self layoutIfNeeded];
}

- (void)layoutSubviews
{
    [super layoutSubviews];
    [self.titleDisplayLabel sizeToFit];
    [self.switchView sizeToFit];
    
    self.titleDisplayLabel.frame = CGRectMake(8, (self.contentView.frame.size.height - self.titleDisplayLabel.frame.size.height)/2, self.titleDisplayLabel.frame.size.width, self.titleDisplayLabel.frame.size.height);
    
    self.switchView.centerY = self.titleDisplayLabel.centerY;
    self.switchView.maxX = self.contentView.width - 8;
    

}

- (void)handlerSwitchValueChange:(UISwitch *)switchView
{
    self.item.switchOn = switchView.isOn;
    !self.item.eventHandler?:self.item.eventHandler(self.item);
}

@end
