//
//  DemoNetworkManager.m
//  OpenSDKDemo
//
//  Created by Jiny.du on 2019/7/10.
//  Copyright © 2019 bytedance.co. All rights reserved.
//
#import "DemoShareConfig.h"
#import "DemoNetworkManager.h"

@implementation DemoNetworkManager
+ (void)fetchShareIdWithStyleID:(NSString *)styleID clientKey:(NSString *)clientKey complete:(void(^)(NSDictionary *rsl, NSInteger status, NSString *errmsg)) complete
{
    [self fetchAccessTokenWithClientKey:clientKey complete:^(NSDictionary * _Nonnull rsl, NSInteger status, NSString * _Nonnull errmsg) {
        if (status != 0) {
            return ;
        }
        NSString *secertKey = rsl[@"data"][@"access_token"];
        NSString *baseURlstring = [NSString stringWithFormat:@"https://open.douyin.com/share-id/?access_token=%@&need_callback=true",secertKey];
        if (styleID && styleID.length > 0) {
            NSString *param = [NSString stringWithFormat:@"&source_style_id=%@",styleID];
            baseURlstring = [baseURlstring stringByAppendingString:param];
        }
        NSURLSession *session = [NSURLSession sharedSession];
        
        //2、利用NSURLSession创建任务(task)
        NSURL *url = [NSURL URLWithString:baseURlstring];
        
        NSURLSessionDataTask *task = [session dataTaskWithURL:url completionHandler:^(NSData * _Nullable data, NSURLResponse * _Nullable response, NSError * _Nullable error) {
            if (!data || error) {
                !complete?:complete(nil, -2, @"NetWorkError");
                return;
            }
            NSString *resultStr = [[NSString alloc]initWithData:data encoding:NSUTF8StringEncoding];
            NSLog(@"fetch Share ID Rsl : %@", resultStr);
            NSError *decode_error;
            NSDictionary *rsl = [NSJSONSerialization JSONObjectWithData:data options:NSJSONReadingMutableContainers error:&decode_error];
            NSInteger status = -1;
            if (decode_error) {
                complete(nil, -2, @"Json Decode Error");
                return;
            }
            if (baseURlstring && baseURlstring.length > 0) {
                status = ((NSNumber *)rsl[@"status"]).integerValue;
            }
            dispatch_async(dispatch_get_main_queue(), ^{
                !complete?:complete(rsl, 0, nil);
            });
        }];
        //3、执行任务
        [task resume];
    }];
}

+ (void)fetchAccessTokenWithClientKey:(NSString *)clientKey complete:(void(^)(NSDictionary *rsl, NSInteger status, NSString *errmsg)) complete
{
    NSDictionary *config = [DemoShareConfig openSDKConfig];
    
    NSString *secret = config[clientKey][@"app_secret"];
    NSString *baseURlstring = [NSString stringWithFormat:@"https://open.douyin.com/oauth/client_token?client_secret=%@&client_key=%@&grant_type=client_credential&",secret,clientKey];
    NSURLSession *session = [NSURLSession sharedSession];
    
    //2、利用NSURLSession创建任务(task)
    NSURL *url = [NSURL URLWithString:baseURlstring];
    
    NSURLSessionDataTask *task = [session dataTaskWithURL:url completionHandler:^(NSData * _Nullable data, NSURLResponse * _Nullable response, NSError * _Nullable error) {
        if (data == nil || error) {
            !complete?:complete(nil, -2, @"fetch AccessToken : NetWorkError");
            return;
        }
        NSError *decode_error;
        NSString *resultStr = [[NSString alloc]initWithData:data encoding:NSUTF8StringEncoding];
        NSLog(@"fetch Share ID Rsl : %@", resultStr);
        
        NSDictionary *rsl = [NSJSONSerialization JSONObjectWithData:data options:NSJSONReadingMutableContainers error:&decode_error];
        NSInteger status = -1;
        if (decode_error) {
            complete(nil, -2, @"fetch AccessToken :Json Decode Error");
            return;
        }
        if (baseURlstring && baseURlstring.length > 0) {
            status = ((NSNumber *)rsl[@"status"]).integerValue;
        }
        !complete?:complete(rsl, 0, nil);
    }];
    //3、执行任务
    [task resume];
}


@end
