//
//  OpenPlatformShareDataControl.m
//  OpenSDKDemo_Example
//
//  Created by Jiny.du on 2019/7/22.
//  Copyright © 2019 bytedance.co All rights reserved.
//
#import "DemoNetworkManager.h"
#import "OpenPlatformShareDataControl.h"
#import "OpenPlatformSession.h"
#import "UIAlertController+Addition.h"

static NSString *const KDefaultStyleID = @"1644278217946120";
static NSString *const KDefaultMicroAppId = @"ttef9b992670b151ec";
@interface OpenPlatformShareDataControl()
@property (nonatomic, strong) DouyinOpenSDKShareRequest *shareReq;
@property (nonatomic, copy  ) NSString *microAppId;
@property (nonatomic, copy  ) NSString *microAppTitle;
@property (nonatomic, copy  ) NSString *microAppDesc;
@property (nonatomic, copy  ) NSString *microAppUrl;
@property (nonatomic, copy  ) NSString *microShareID;

@property (nonatomic, copy ) NSString *styleID;
@property (nonatomic, assign, readwrite) NSInteger type;
@property (nonatomic, copy, readwrite) NSArray <OpenPlatformSession *> *sessions;
@property (nonatomic, strong) OpenPlatformSession *shareMetaDataSection;

@end

@implementation OpenPlatformShareDataControl

- (instancetype) initWithAppType:(NSInteger)type
{
    self = [super init];
    if (self) {
        _type = type;
        self.sessions = @[self.shareMetaDataSection];
        self.shareReq = [[DouyinOpenSDKShareRequest alloc] init];
    }
    return self;
}

- (OpenPlatformSession *)shareMetaDataSection
{
    if (!_shareMetaDataSection) {
        _shareMetaDataSection = [[OpenPlatformSession alloc] init];
        _shareMetaDataSection.sessionTitle = @"Share Meta Info";
        _shareMetaDataSection.sessionDesc  = @"Share extra info";
        
        NSMutableArray *m_arr = [NSMutableArray array];
        __weak typeof(self) ws = self;
        
        OpenPlatformDataItem *item1 = [OpenPlatformDataItem  itemForEditWithTitle:@"Hash Tag" context:nil placehold:@"HashTag need open in Web" eventHandler:^(OpenPlatformDataItem * _Nonnull item) {
            ws.shareReq.hashtag = item.editText;
        }];
        [m_arr addObject:item1];
        
        OpenPlatformDataItem *item2 = [OpenPlatformDataItem  itemForEditAndBtnWithTitle:@"Micro App ID" placehold:nil context:nil btnTitle:@"Def" eventHandler:^(OpenPlatformDataItem * _Nonnull item) {
            ws.microAppId = item.editText;
        } tapHandeler:^(OpenPlatformDataItem * _Nonnull item) {
            ws.microAppId = KDefaultMicroAppId;
            item.editText = KDefaultMicroAppId;
            [ws notifyDataChange];
        }];
        
        [m_arr addObject:item2];
        
        OpenPlatformDataItem *item3 = [OpenPlatformDataItem  itemForEditWithTitle:@"Micro App Title" context:nil placehold:@"Micro App title" eventHandler:^(OpenPlatformDataItem * _Nonnull item) {
            ws.microAppTitle = item.editText;
        }];
        [m_arr addObject:item3];
        
        OpenPlatformDataItem *item4 = [OpenPlatformDataItem  itemForEditWithTitle:@"Micro App Desc" context:nil placehold:@"Micro App Desc" eventHandler:^(OpenPlatformDataItem * _Nonnull item) {
            ws.microAppDesc = item.editText;
        }];
        [m_arr addObject:item4];
        
        OpenPlatformDataItem *item5 = [OpenPlatformDataItem  itemForEditWithTitle:@"Micro App Link" context:nil placehold:@"Micro App Link" eventHandler:^(OpenPlatformDataItem * _Nonnull item) {
            ws.microAppUrl = item.editText;
        }];
        [m_arr addObject:item5];
     
        OpenPlatformDataItem *item7 = [OpenPlatformDataItem  itemForEditAndBtnWithTitle:@"Style ID" placehold:nil context:nil btnTitle:@"Def" eventHandler:^(OpenPlatformDataItem * _Nonnull item) {
            ws.microAppId = item.editText;
        } tapHandeler:^(OpenPlatformDataItem * _Nonnull item) {
            ws.styleID = KDefaultStyleID;
            item.editText = KDefaultStyleID;
            [ws notifyDataChange];
        }];
        
        [m_arr addObject:item7];
        
        
        OpenPlatformDataItem *item6 =  [OpenPlatformDataItem  itemForEditAndBtnWithTitle:@"Share ID" placehold:nil context:nil btnTitle:@"Req" eventHandler:^(OpenPlatformDataItem * _Nonnull item) {
            ws.microShareID = item.editText;
        } tapHandeler:^(OpenPlatformDataItem * _Nonnull item) {
            [ws requestShareIDWithStyle:ws.styleID completed:^(NSString *shareID) {
                ws.microShareID = shareID;
                item.editText = shareID;
                [ws notifyDataChange];
            }];
    
        }];
        [m_arr addObject:item6];
        _shareMetaDataSection.items = m_arr.copy;
    }
    return _shareMetaDataSection;
}

- (void)notifyDataChange;
{
    NSIndexPath *indexPath = [NSIndexPath indexPathForRow:0 inSection:0];
    !self.dataSoureChange?:self.dataSoureChange(indexPath);
}


- (void)requestShareIDWithStyle:(NSString *)styleID completed:(void(^)(NSString *shareID)) complete
{
    NSString *appID = [[DouyinOpenSDKApplicationDelegate sharedInstance] appId];
    [DemoNetworkManager fetchShareIdWithStyleID:styleID clientKey:appID complete:^(NSDictionary * _Nonnull rsl, NSInteger status, NSString * _Nonnull errmsg) {
        if (status == 0 && rsl[@"data"][@"share_id"]) {
            
            !complete?:complete(rsl[@"data"][@"share_id"]);
            return;
        }
        NSLog(@"request ShareID failed");
    }];
}

- (void) shareMediaIds:(NSArray *)media type:(DouyinOpenSDKShareMediaType) type
{
    //构造小程序信息
    NSMutableDictionary *m_map_info = @{}.mutableCopy;
    m_map_info[@"identifier"] = self.microAppId?:@"";
    m_map_info[@"title"] = self.microAppTitle?:@"";
    m_map_info[@"desc"] = self.microAppDesc?:@"";
    m_map_info[@"startPageURL"] = self.microAppUrl?:@"";
    
    //构造和视频版定的额外信息
    NSMutableDictionary *m_product_extra_info = @{}.mutableCopy;
    if (self.styleID.length > 0) {
        m_product_extra_info[@"styleID"] = self.styleID;
    }
    
    self.shareReq.localIdentifiers = media;
    self.shareReq.mediaType = type;
    self.shareReq.state = self.microShareID;
    NSMutableDictionary *m_extra_info = @{
                                          @"mpInfo" : m_map_info.copy,
                                          }.mutableCopy;
    if (m_product_extra_info.count > 0) {
        m_extra_info[@"product_extra_info"] = m_product_extra_info.copy;
    }
    self.shareReq.extraInfo = m_extra_info.copy;
    
    [self.shareReq sendShareRequestWithCompleteBlock:^(DouyinOpenSDKShareResponse * _Nonnull Response) {
        NSString *alertString = nil;
        if (Response.errCode == 0) {
            alertString = [NSString stringWithFormat:@"Share succeed"];
        } else{
            alertString = [NSString stringWithFormat:@"Share failed error code : %@ , error msg : %@", @(Response.errCode), Response.errString];
        }
        [UIAlertController showMsg:alertString inVC:[UIApplication sharedApplication].keyWindow.rootViewController];
    }];
}
    


@end

