//
//  OpenPlatformShareViewController.m
//  OpenSDKDemo_Example
//
//  Created by Jiny.du on 2019/7/22.
//  Copyright © 2019 bytedance.co All rights reserved.
//
#import "OpenPlatformUIDefine.h"
#import "OpenPlatformShareViewController.h"
#import "OpenPlatformSectionCell.h"
#import "OpenPlatformShareDataControl.h"
#import "OpenPlatformSession.h"
#import "OpenPlatformCellProtocol.h"
#import "OpenPlatformActionView.h"
#import "UIAlertController+Addition.h"
#import "QBImagePickerController.h"

@interface OpenPlatformShareViewController ()<QBImagePickerControllerDelegate, UITableViewDelegate, UITableViewDataSource>
@property (nonatomic, strong) UITableView *tableView;
@property (nonatomic, strong) OpenPlatformShareDataControl *dataControl;
@property (nonatomic, strong) OpenPlatformActionView *actionView;
@end

@implementation OpenPlatformShareViewController

#pragma mark - QBImagePickerControllerDelegate

- (void)qb_imagePickerController:(QBImagePickerController *)imagePickerController didFinishPickingAssets:(NSArray *)assets {
    NSMutableArray *ids = [NSMutableArray array];
    for (PHAsset *asset in assets) {
        if (![asset isKindOfClass:[PHAsset class]]) {
            NSAssert(NO, @"");
            continue;
        }
        
        [ids addObject:asset.localIdentifier];
    }
    
    if (imagePickerController.mediaType == QBImagePickerMediaTypeVideo) {
        [self.dataControl shareMediaIds:ids type:DouyinOpenSDKShareMediaTypeVideo];
    } else if (imagePickerController.mediaType == QBImagePickerMediaTypeImage) {
        [self.dataControl shareMediaIds:ids type:DouyinOpenSDKShareMediaTypeImage];
    }
    
    [imagePickerController dismissViewControllerAnimated:YES completion:nil];
}

- (void)qb_imagePickerControllerDidCancel:(QBImagePickerController *)imagePickerController {
    [imagePickerController dismissViewControllerAnimated:YES completion:nil];
}
- (void)viewDidLoad {
    [super viewDidLoad];
    self.view.backgroundColor = [UIColor demo_colorWithHex:@"#f5f5f5"];
    self.tableView = [[UITableView alloc] initWithFrame:self.view.frame style:UITableViewStyleGrouped];
    self.tableView.dataSource = self;
    self.tableView.delegate  = self;
    self.tableView.backgroundColor = YAMBGDefualtColor;
    self.tableView.separatorStyle = UITableViewCellSeparatorStyleNone;
    [self.tableView registerClass:[OpenPlatformSectionCell class]
           forCellReuseIdentifier:@"OpenPlatformSession"];
    self.tableView.contentInset = UIEdgeInsetsMake(0, 0, 20, 0);
    [self.view addSubview:self.tableView];
    
    self.title = @"China Share";
    
    
    self.actionView = [[OpenPlatformActionView alloc] initWithFrame:CGRectZero];
    [self.actionView.leftButton setTitle:@"Share Img" forState:UIControlStateNormal];
    [self.actionView.rightButton setTitle:@"Share Video" forState:UIControlStateNormal];
    [self.actionView.leftButton addTarget:self action:@selector(tapShareImage) forControlEvents:UIControlEventTouchUpInside];
    [self.actionView.rightButton addTarget:self action:@selector(tapShareVideo) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:self.actionView];
}

- (void)viewDidLayoutSubviews
{
    [super viewDidLayoutSubviews];
    self.tableView.frame = self.view.bounds;
    self.actionView.x = 0;
    self.actionView.width = self.view.width;
    self.actionView.height = 60 + BOTTOM_SAFEAREA_HEIGHT;
    self.actionView.y = self.view.height - BOTTOM_SAFEAREA_HEIGHT - 60;
    [self.actionView setNeedsLayout];
    [self.actionView layoutIfNeeded];
}

- (void)setAppType:(NSInteger)appType
{
    _appType = appType;
    __weak typeof(self) ws = self;
    self.dataControl = [[OpenPlatformShareDataControl alloc] initWithAppType:appType];
    self.dataControl.dataSoureChange = ^(NSIndexPath *indexPath) {
        if (!indexPath) {
            [ws.tableView reloadData];
            return;
        }
        UITableViewCell *cell = [ws.tableView cellForRowAtIndexPath:indexPath];
        if (cell) {
            [UIView performWithoutAnimation:^{
                [ws.tableView reloadRowsAtIndexPaths:@[indexPath] withRowAnimation:UITableViewRowAnimationNone];
            }];
        }
        
    };

    [self.tableView reloadData];
}

- (void)tapShareImage
{
    [self showImageSelectVCWithMediaType:QBImagePickerMediaTypeImage];
}

- (void)tapShareVideo
{
    [self showImageSelectVCWithMediaType:QBImagePickerMediaTypeVideo];

}

- (void)showImageSelectVCWithMediaType:(QBImagePickerMediaType)mediaType {
    QBImagePickerController *imagePickerVC = [[QBImagePickerController alloc] init];
    imagePickerVC.delegate = self;
    imagePickerVC.allowsMultipleSelection = YES;
    imagePickerVC.maximumNumberOfSelection = 12;
    imagePickerVC.showsNumberOfSelectedAssets = YES;
    imagePickerVC.mediaType = mediaType;
    
    [self presentViewController:imagePickerVC animated:YES completion:NULL];
}

#pragma mark - TableView Delegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    [tableView deselectRowAtIndexPath:indexPath animated:NO];
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath
{
    return self.dataControl.sessions[indexPath.section].heightForSession;
}

- (CGFloat)tableView:(UITableView *)tableView heightForFooterInSection:(NSInteger)section
{
    return .1f;
}

- (CGFloat)tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section
{
    return 25.f;
}

- (UIView *)tableView:(UITableView *)tableView viewForFooterInSection:(NSInteger)section
{
    return [[UIView alloc] init];
}

- (void)scrollViewDidScroll:(UIScrollView *)scrollView
{
    [self.view endEditing:YES];
}

#pragma mark - TableView DataSource
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    OpenPlatformSession *item = self.dataControl.sessions[indexPath.row];
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:NSStringFromClass([OpenPlatformSession class])];
    if ([cell conformsToProtocol:@protocol(OpenPlatformSectionProtocol)]) {
        [((id<OpenPlatformSectionProtocol>)cell) configWithSectionItem:item];
    }
    return cell;
}

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return self.dataControl.sessions.count;
}
@end
